My Crate
my_crate is a collection of utilities to make performing certain
calculations more convenient.
Re-exports
pub use self::utils::mix;pub use self::kinds::PrimaryColor;pub use self::kinds::SecondaryColor;
my_crate is a collection of utilities to make performing certain
calculations more convenient.
pub use self::utils::mix;pub use self::kinds::PrimaryColor;pub use self::kinds::SecondaryColor;